@@ -36,41 +36,15 @@ import os
 import sys
 import logging
 
-from hubzero.submit.DaemonsInfo         import DaemonsInfo
-from hubzero.submit.RemoteTunnelMonitor import RemoteTunnelMonitor
+from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
+from hubzero.submit.DaemonsInfo          import DaemonsInfo
+from hubzero.submit.RemoteTunnelMonitor  import RemoteTunnelMonitor
 
-CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
+SUBMITUTILITYLOGLEVEL = "ERROR"
+
+DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
 DAEMONSCONFIGURATIONFILE = 'daemons.conf'
 
-APPLICATIONLOGGER = logging.getLogger('') 
-
-def openLogger():
-   class EmptyFilter(logging.Filter):
-      """
-      This is a filter which rejects empty messages
-
-      """
-
-      def filter(self,record):
-         if record.getMessage() == "":
-            emptyRecord = True
-         else:
-            emptyRecord = False
-
-         return(not emptyRecord)
-
-   APPLICATIONLOGGER.setLevel(logging.DEBUG)
-
-   logHandler = logging.StreamHandler()
-
-   emptyFilter = EmptyFilter()
-   logHandler.addFilter(emptyFilter)
-
-   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
-   logHandler.setFormatter(logFormatter)
-   APPLICATIONLOGGER.addHandler(logHandler)
-
-
 def monitorTunnelA(listenURI):
    """Get ssh tunnel Address and port"""
    tunnelName = sys.argv[1]
@@ -82,9 +56,15 @@ def monitorTunnelA(listenURI):
 
 
 if __name__ == '__main__':
-   openLogger()
+   submitUtilityLogLevel    = os.getenv("SUBMITUTILITYLOGLEVEL",SUBMITUTILITYLOGLEVEL)
+   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
+   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
 
-   configFilePath = os.path.join(CONFIGURATIONDIRECTORY,DAEMONSCONFIGURATIONFILE)
+   applicationUtilities = ApplicationUtilities(SUBMITUTILITYLOGLEVEL)
+   applicationUtilities.openStreamLogger(sys.stderr,
+                                         submitUtilityLogLevel)
+
+   configFilePath = os.path.join(daemonsDirectory,daemonsConfigurationFile)
    daemonsInfo    = DaemonsInfo(configFilePath)
    listenURI      = daemonsInfo.getDaemonListenURI('tunnelMonitor','tcp')
 
